1
0
mirror of https://github.com/gryf/gryf-overlay.git synced 2026-02-24 20:45:49 +01:00

initial import

This commit is contained in:
root
2010-02-09 21:25:29 +01:00
commit b2719dc011
1080 changed files with 41656 additions and 0 deletions

View File

@@ -0,0 +1,100 @@
# ChangeLog for x11-plugins/wmpower
# Copyright 1999-2007 Gentoo Foundation; Distributed under the GPL v2
# $Header: /var/cvsroot/gentoo-x86/x11-plugins/wmpower/ChangeLog,v 1.27 2007/02/21 23:48:06 jokey Exp $
21 Feb 2007; Markus Ullmann <jokey@gentoo.org> ChangeLog:
Redigest for Manifest2
08 Feb 2006; Michele Noberasco <s4t4n@gentoo.org> wmpower-0.4.1.ebuild:
Wiped out older release.
07 Feb 2006; Simon Stelling <blubb@gentoo.org> wmpower-0.4.2.ebuild:
stable on amd64.
31 Jan 2006; Krzysiek Pawlik <nelchael@gentoo.org> wmpower-0.4.1.ebuild,
wmpower-0.4.2.ebuild:
Fixed DEPEND for modular X.
07 Nov 2005; Michele Noberasco <s4t4n@gentoo.org> wmpower-0.4.2.ebuild,
wmpower-0.4.1.ebuild:
Removed COPYING from dodoc.
19 Aug 2005; Michael Hanselmann <hansmi@gentoo.org> wmpower-0.4.2.ebuild:
Stable on ppc.
19 Aug 2005; Michele Noberasco <s4t4n@gentoo.org> wmpower-0.4.2.ebuild:
Stable for x86.
*wmpower-0.4.2 (22 Jul 2005)
22 Jul 2005; Michele Noberasco <s4t4n@gentoo.org> wmpower-0.4.2.ebuild:
Version bump.
23 May 2005; Michele Noberasco <s4t4n@gentoo.org> wmpower-0.3.1.ebuild:
Wiped out older version.
01 May 2005; Michael Hanselmann <hansmi@gentoo.org> wmpower-0.4.1.ebuild:
Stable on ppc.
20 Apr 2005; Simon Stelling <blubb@gentoo.org> wmpower-0.4.1.ebuild:
stable on amd64
07 Mar 2005; Michele Noberasco <s4t4n@gentoo.org> wmpower-0.4.1.ebuild:
Stable for x86.
wmpower-0.4.0.ebuild:
Removed older version.
*wmpower-0.4.1 (25 Feb 2005)
25 Feb 2005; Michele Noberasco <s4t4n@gentoo.org> wmpower-0.4.1.ebuild:
Version bump.
*wmpower-0.4.0 (23 Feb 2005)
23 Feb 2005; Michele Noberasco <s4t4n@gentoo.org> wmpower-0.4.0.ebuild:
Version bump. Added ~ppc keyword as I got positive feedback on CVS version.
25 Jan 2005; Michele Noberasco <s4t4n@gentoo.org> wmpower-0.3.1.ebuild:
Update Copyright headers
13 Nov 2004; Michele Noberasco <s4t4n@gentoo.org> wmpower-0.3.1.ebuild:
Remove no longer needed eutils inheritance...
12 Nov 2004; Michele Noberasco <s4t4n@gentoo.org> wmpower-0.3.0.ebuild:
Remove older ebuild...
19 Oct 2004; Dylan Carlson <absinthe@gentoo.org> wmpower-0.3.1.ebuild:
Stable on amd64.
30 Jun 2004; Michele Noberasco <s4t4n@gentoo.org> wmpower-0.3.1.ebuild:
Stable on x86.
wmpower-0.1.2.ebuild, wmpower-0.1.3.ebuild:
Wipe out old versions.
*wmpower-0.3.1 (22 Jun 2004)
22 Jun 2004; Michele Noberasco <s4t4n@gentoo.org> wmpower-0.3.1.ebuild:
Version Bump. Closes #45076.
The cflags.patch is no longer needed as the problem was fixed upstream.
wmpower-0.1.3.ebuild, wmpower-0.1.2.ebuild:
Fix the Copyright headers to make repoman happy
*wmpower-0.3.0 (22 Oct 2003)
22 Oct 2003; Markus Nigbur <pyrania@gentoo.org> wmpower-0.3.0.ebuild:
Version Bump. Thanks to Michele Noberasco (#31738).
12 Jun 2003; Seemant Kulleen <seemant@gentoo.org> wmpower-0.1.2.ebuild,
wmpower-0.1.3.ebuild:
xpm is provided by xfree
*wmpower-0.1.3 (06 Jun 2003)
06 Jun 2003; robh <robh@gentoo.org> wmpower-0.1.3.ebuild:
version bump, noted by Noberasco Michele, closes #22250
*wmpower-0.1.2 (03 Jun 2003)
03 Jun 2003; Brad Cowan <bcowan@gentoo.org> wmpower-0.1.2.ebuild:
Initial import. Thanks to Noberasco Michele bug #17963.

View File

@@ -0,0 +1,20 @@
AUX wmpower_command.patch 6766 RMD160 ee418b07c2c50e4fe58152bf5c9434245b247104 SHA1 0e05214fb7b7e5541440dd7df70a52b905cdaa9e SHA256 362ac43c2472996cd256b86efce65534c93182f2797227c9b31e4de73b2c526a
MD5 285ddf48ce805bc0bf94bef2b06f6348 files/wmpower_command.patch 6766
RMD160 ee418b07c2c50e4fe58152bf5c9434245b247104 files/wmpower_command.patch 6766
SHA256 362ac43c2472996cd256b86efce65534c93182f2797227c9b31e4de73b2c526a files/wmpower_command.patch 6766
DIST wmpower-0.4.2.tar.bz2 96403 RMD160 962b6590ef1a8056d8fa421ede7cd1399c883847 SHA1 e7bf92b317a006ca4969369d01e88456c2f47fdc SHA256 cfef1b38dca32259742b36be2ba9c0dcde88d035e31ae8af84c2e33108dee426
EBUILD wmpower-0.4.2-r10.ebuild 1146 RMD160 79f5070213afb868423203584c0c34175de02eea SHA1 e18da54d7e27e476638ff7b9e60fc300af1a4e89 SHA256 66e7c095c42cdf8efbe33e542a091f1df45a7150e9223fd96e7c2732041ffed4
MD5 a407f2607a3ef31e455b9afebe1bff92 wmpower-0.4.2-r10.ebuild 1146
RMD160 79f5070213afb868423203584c0c34175de02eea wmpower-0.4.2-r10.ebuild 1146
SHA256 66e7c095c42cdf8efbe33e542a091f1df45a7150e9223fd96e7c2732041ffed4 wmpower-0.4.2-r10.ebuild 1146
MISC ChangeLog 3265 RMD160 93afa0407e5e84ea6aa7f001813286d45f6203a7 SHA1 2fbfbe5a6dc8ecc2d99c891c31f3e49cc04ebac8 SHA256 e7ab96ad2f60f529d65d4e1d45bd69e5c5cf0efa3df569ec422d4afddeaa124a
MD5 29edf99095bf3649befe6dedd1887f2b ChangeLog 3265
RMD160 93afa0407e5e84ea6aa7f001813286d45f6203a7 ChangeLog 3265
SHA256 e7ab96ad2f60f529d65d4e1d45bd69e5c5cf0efa3df569ec422d4afddeaa124a ChangeLog 3265
MISC metadata.xml 519 RMD160 6112620554c5d9f985e572e5e90c2888890fd564 SHA1 41744a08ae038fc19e559d60d43af2da61e1617f SHA256 235383888d64e289fefa36b456782e518f1af8bfac5a7e36c80112ff4d17e837
MD5 e4a837b9af84bef3c70c3974bc982d71 metadata.xml 519
RMD160 6112620554c5d9f985e572e5e90c2888890fd564 metadata.xml 519
SHA256 235383888d64e289fefa36b456782e518f1af8bfac5a7e36c80112ff4d17e837 metadata.xml 519
MD5 acacb54055922c77ca40b7d4c4d21273 files/digest-wmpower-0.4.2-r10 241
RMD160 d42672aaeb8ff60c2c05a3d806b37a4deed17371 files/digest-wmpower-0.4.2-r10 241
SHA256 520abec2a41ee3e119a40523eddbe3e0a256b5d76de0f6a7220117600fd451c4 files/digest-wmpower-0.4.2-r10 241

View File

@@ -0,0 +1,3 @@
MD5 b16d8125b852fc680fee23538429a049 wmpower-0.4.2.tar.bz2 96403
RMD160 962b6590ef1a8056d8fa421ede7cd1399c883847 wmpower-0.4.2.tar.bz2 96403
SHA256 cfef1b38dca32259742b36be2ba9c0dcde88d035e31ae8af84c2e33108dee426 wmpower-0.4.2.tar.bz2 96403

View File

@@ -0,0 +1,137 @@
--- wmpower-0.4.2/src/wmpower.c 2005-07-15 18:43:35.000000000 +0200
+++ wmpower-0.4.2r10/src/wmpower.c 2007-07-05 13:08:06.000000000 +0200
@@ -54,14 +54,15 @@
void ShowBatteryPercentage(int percentage);
void ShowBatteryLed(int present, int percentage, int ac_on_line);
-int no_meddling = 0; /* Should we stop managing power status? */
+int no_meddling = 1; /* Should we stop managing power status? */
int no_full_battery = 0; /* Should we always use max power when plugged? */
int CriticalLevel = 10; /* Battery critical level */
-int LowLevel = 40; /* Battery low level */
+int LowLevel = 50; /* Battery low level */
#define CMDLINELEN 512
-int WarnTime = 2; /* When to execute the warn command */
+int CriticalPercent = 10; /* Battery low percent, when execute warn command */
+int WarnTime = 8; /* When to execute the warn command */
char WarnCommand[CMDLINELEN] = ""; /* The warn command to execute */
float BlinkRate = 3.00; /* blinks per second */
@@ -98,7 +99,13 @@
BlinkRate = (BlinkRate >= 0.0) ? BlinkRate : -1.0 * BlinkRate;
waittime = 0; /* /proc polling interval */
-
+
+ /* det default */
+ set_noflushd_use(0);
+ set_lin_seti_use(0);
+ set_toshiba_hardware_use(0);
+ set_cpufreq_use(0);
+
fprintf(stderr, "\nWelcome to wmpower version %s...\n", VERSION);
cpufreq_online_governor = NULL;
@@ -164,13 +171,15 @@
set_pm_features();
}
- /* Execute the warning command, if needed */
- if (WarnCommand && *WarnCommand && !power_status.ac_on_line && !warned
- && power_status.battery_time <= WarnTime)
- {
+ /* Execute the warning command, if needed
+ * But, look at percentage usage instead of remaining time.
+ */
+ if (WarnCommand && *WarnCommand && !power_status.ac_on_line && !warned){
+ if(power_status.battery_percentage <= CriticalPercent && power_status.battery_time <= WarnTime || power_status.battery_percentage == 1){
warned = 1;
sprintf(Command, "%s &", WarnCommand);
system(Command);
+ }
}
if (power_status.ac_on_line)
warned = 0;
@@ -352,7 +361,7 @@
copyXPMArea ((temp % 10) * 6 + 4, 69, 6, 7, 39, 50);
}
- /* Plot the ° Symbol */
+ /* Plot the � Symbol */
copyXPMArea (135, 60, 6, 7, 45, 50);
/* Plot the C Symbol */
@@ -449,30 +458,33 @@
printf("\nkernels, plus special support for Toshiba and Compal hardware.");
printf("\n\nUsage: wmpower [options]\n");
printf("\n\nOptions:\n");
- printf("\t-no-meddling\t\tDon't manage power status, just show info.\n");
+ printf("\t-meddling\t\tmanage power status, just show info.\n");
printf("\t-no-full-battery\tDon't wait for 100%% battery before going back\n");
printf("\t\t\t\tto full power.\n");
- printf("\t-no-cpufreq\t\tDon't scale CPU frequency according to power status.\n");
- printf("\t-no-noflushd\t\tDisable use of \"noflushd\" daemon:\n");
+ printf("\t-cpufreq\t\tScale CPU frequency according to power status.\n");
+ printf("\t-noflushd\t\tEnable use of \"noflushd\" daemon:\n");
printf("\t\t\t\tnoflushd is a tool for managing spin-down\n");
printf("\t\t\t\tof hard disks after a certain amount of time\n");
printf("\t\t\t\tsee <http://noflushd.sourceforge.net> for details.\n");
- printf("\t-no-lin-seti\t\tDon't manage \"lin-seti\" daemon:\n");
+ printf("\t-lin-seti\t\tManage \"lin-seti\" daemon:\n");
printf("\t\t\t\t\"lin-seti\" is a Seti@Home cache manager that can\n");
printf("\t\t\t\twork as a daemon. For details go to\n");
printf("\t\t\t\t<http://sourceforge.net/projects/lin-seti/>.\n");
- printf("\t-no-toshiba\t\tDisable direct access to toshiba hardware,\n");
+ printf("\t-toshiba\t\tEnable direct access to toshiba hardware,\n");
printf("\t\t\t\tuse only generic ACPI/APM calls instead.\n");
printf("\t\t\t\tThis is recommended on newer toshibas.\n");
printf("\t-battery <num>\t\tMonitor your nth battery instead of first one.\n");
printf("\t-display <display>\tUse alternate display.\n");
printf("\t-geometry <geometry>\twmpower window geometry.\n");
printf("\t-l\t\t\tUse a low-color pixmap.\n");
- printf("\t-L <LowLevel>\t\tDefine level at which yellow LED turns on.\n");
- printf("\t-C <CriticalLevel>\tDefine level at which red LED turns on.\n");
+ printf("\t-L <LowLevel>\t\tDefine battery level at which yellow LED turns on (50%).\n");
+ printf("\t-C <CriticalLevel>\tDefine battery level at which red LED turns on (10%).\n");
printf("\t-B <Volume>\t\tBeep at Critical Level (-100%% to 100%%).\n");
+ printf("\t-P <percent>\t\tWarn command to run when remaining battery percentage is achieved (30%).\n");
+ printf("\t-W <minutes>\t\tMinutes of remaining time when to run warn command (8min).\n");
+ printf("\t\t\t\tComand will be executed only, when remaining time and percentage of\n");
+ printf("\t\t\t\tbattery borders are crossed.\n");
printf("\t-w <command>\t\tWarn command to run when remaining time is low.\n");
- printf("\t-W <minutes>\t\tMinutes of remaining time when to run warn command.\n");
printf("\t-u <seconds>\t\tSet wmpower polling interval.\n");
printf("\t-g <governor>\t\tUse this CPUFreq scaling governor while running on battery power.\n");
printf("\t-G <governor>\t\tUse this CPUFreq scaling governor while running on AC power.\n");
@@ -536,6 +548,11 @@
if (argc == i+1) message();
LowLevel = atoi (argv[++i]);
break;
+ case 'P':
+ if (cmdline[2] != '\0') message();
+ if (argc == i+1) message();
+ CriticalPercent = atoi (argv[++i]);
+ break;
case 'l':
if (cmdline[2] != '\0') message();
UseLowColorPixmap = 1;
@@ -569,12 +586,12 @@
open_syslog_on_stderr();
break;
case 'n':
- if (!strcmp(cmdline, "-no-meddling")) {no_meddling = 1; break;}
+ if (!strcmp(cmdline, "-meddling")) {no_meddling = 0; break;}
if (!strcmp(cmdline, "-no-full-battery")) {no_full_battery = 1; break;}
- if (!strcmp(cmdline, "-no-noflushd")) {set_noflushd_use(0); break;}
- if (!strcmp(cmdline, "-no-lin-seti")) {set_lin_seti_use(0); break;}
- if (!strcmp(cmdline, "-no-toshiba")) {set_toshiba_hardware_use(0); break;}
- if (!strcmp(cmdline, "-no-cpufreq")) {set_cpufreq_use(0); break;}
+ if (!strcmp(cmdline, "-noflushd")) {set_noflushd_use(1); break;}
+ if (!strcmp(cmdline, "-lin-seti")) {set_lin_seti_use(1); break;}
+ if (!strcmp(cmdline, "-toshiba")) {set_toshiba_hardware_use(1); break;}
+ if (!strcmp(cmdline, "-cpufreq")) {set_cpufreq_use(1); break;}
default:
message();
}

View File

@@ -0,0 +1,11 @@
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE pkgmetadata SYSTEM "http://www.gentoo.org/dtd/metadata.dtd">
<pkgmetadata>
<herd>desktop-dock</herd>
<longdescription>
wmpower is a Window Maker dock application
allowing the user to graphically see (and set) the power management status of his laptop.
It works with both APM and ACPI enabled kernels, has special support for Toshiba, Compal
and Dell hardware, and allows you to dinamically set the frequency of your CPU(s) via CPUfreq.
</longdescription>
</pkgmetadata>

View File

@@ -0,0 +1,45 @@
# Copyright 1999-2006 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: /var/cvsroot/gentoo-x86/x11-plugins/wmpower/wmpower-0.4.2.ebuild,v 1.6 2006/02/07 21:14:22 blubb Exp $
IUSE=""
inherit eutils
DESCRIPTION="WMaker DockApp to get (and set) power management status for laptops. Supports APM and ACPI kernels. Supports CPUfreq. Also has special support for Toshiba, Dell and Compal hardware."
HOMEPAGE="http://wmpower.sourceforge.net/"
SRC_URI="mirror://sourceforge/wmpower/${P}.tar.bz2"
LICENSE="GPL-2"
SLOT="0"
KEYWORDS="amd64 ppc x86"
RDEPEND="|| ( (
x11-libs/libX11
x11-libs/libXext
x11-libs/libXpm )
virtual/x11 )"
DEPEND="${RDEPEND}
|| ( (
x11-proto/xproto
x11-proto/xextproto )
virtual/x11 )"
src_unpack() {
unpack ${A}
epatch "${FILESDIR}/wmpower_command.patch"
}
src_compile()
{
# override wmpower self-calculated cflags
econf MY_CFLAGS="${CFLAGS}" || die "Configuration failed"
emake prefix="/usr/" || die "Compilation failed"
}
src_install()
{
einstall || die "Installation failed"
dodoc AUTHORS BUGS ChangeLog LEGGIMI NEWS README README.compal THANKS TODO
}